@@ -1,9 +1,10 @@
 package Module::Faker::File;
 {
-  $Module::Faker::File::VERSION = '0.010';
+  $Module::Faker::File::VERSION = '0.011';
 }
 use Moose;
 with 'Module::Faker::Appendix';
+# ABSTRACT: a fake file in a fake dist
 
 has filename => (is => 'ro', isa => 'Str', required => 1);
 has content  => (is => 'ro', isa => 'Str', required => 1);
@@ -18,11 +19,11 @@ __END__
 
 =head1 NAME
 
-Module::Faker::File
+Module::Faker::File - a fake file in a fake dist
 
 =head1 VERSION
 
-version 0.010
+version 0.011
 
 =head1 AUTHOR
 
